@@ -32,7 +32,7 @@ eval 'use Net::OpenSSH; use IO::Pty; $haveit{"openssh"} = 1; 1';
 eval 'use Net::FSP; $haveit{"fsp"} = 1; 1';
 eval 'use Net::FTPSSL; $haveit{"ftpssl"} = 1; 1';
 
-our $VERSION = '0.52';
+our $VERSION = '1.00';
 
 sub new
 {
@@ -57,9 +57,6 @@ sub new
 			delete $args{"xftp_$i"};
 		}
 	}
-#print "-???- pkg=$pkg= havit=".$haveit{'ftpssl'}."=\n";
-#foreach my $xxx (sort keys %haveit) { print "--haveit($xxx)=$haveit{$xxx}=\n"; };
-#	if ($pkg =~ /Net::FTPSSL/o && $haveit{'ftpssl'})
 	if ($pkg =~ /Net::FTPSSL/)
 	{
 		eval { require "Net/xFTP_FTPSSL.pm" };
@@ -320,15 +317,16 @@ __END__
 
 =head1 NAME
 
-Net::xFTP - Common wrapper functions for use with either Net::FTP or Net::xFTP.
+Net::xFTP - Common wrapper functions for use with either Net::FTP, Net::SFTP, 
+Net::FSP, Net::FTPSSL, Net::OpenSSH, Net:SSH2, and Net::SFTP::Foreign.
 
 =head1 AUTHOR
 
-Jim Turner, C<< <http://home.mesh.net/turnerjw/jim> >>
+Jim Turner, C<< <mailto:turnerjw784@yahoo.com> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005 Jim Turner <http://home.mesh.net/turnerjw/jim>.  
+Copyright (c) 2005-2015 Jim Turner <mailto:turnerjw784@yahoo.com>.  
 All rights reserved.  
 
 This program is free software; you can redistribute 
@@ -349,13 +347,14 @@ Many thanks go to these gentlemen whose work made this module possible.
 	die "..This server connection needs Net::SFTP!" 
 		unless (Net::xFTP->haveModule('Net::SFTP'));
 
-	#Establish a new connection to a remote host.
+	#Example 1:  Establish a new SFTP connection to a remote host.
 	$ftp = Net::xFTP->new('SFTP', "some.host.name", Debug => 0,
 			user => 'userid', password => 'opensesme')
 		or die "Cannot connect to some.host.name: $@";
 
-	#Establish a "local" (simulated connection) to self.
-	$ftp = Net::xFTP->new();
+	#Example 2:  Establish a "local" (simulated connection) to self.
+	$ftp = Net::xFTP->new();  # -OR-
+	$ftp = Net::xFTP->new('Local');
 
 	#Change the current working directory on the remote host.
 	$ftp->cwd('/pub')  or die 
@@ -427,6 +426,9 @@ Many thanks go to these gentlemen whose work made this module possible.
 	$ftp->move('old/path/old.filename', 'new/path/new.filename')
 		or die "Cannot move the file ", $ftp->message();
 
+	#Call a protocol-specific method.
+	$result = $ftp->method('timeout',100)
+
 	#Disconnect an existing connection.
 	$ftp->quit();
 
@@ -434,7 +436,7 @@ Many thanks go to these gentlemen whose work made this module possible.
 
 Even though Net::xFTP will work in a connection-simulating "I<local>" mode, 
 to be truly useful, one needs either C<Net::FTP>, C<Net::SFTP>, or 
-preferrably both.  
+one or more of the other supported Net::* protocol modules.
 
 C<Net::SFTP::Attributes> is also needed, if using Net::SFTP.
 
@@ -443,12 +445,13 @@ I<move> functions, or using the I<put> function with a filehandle.
 
 =head1 DESCRIPTION
 
-C<Net::xFTP> is a wrapper class to combine common functions of Net::FTP and 
-Net::SFTP into a single set of functions allowing one to switch seemlessly 
-between the two without having to make non-trivial code changes.  Only  
-functionality common to both protocols has been implemented here with the 
-intent and invitation to add more functions and features and mayby other 
-*FTP-ish modules in the future.
+C<Net::xFTP> is a wrapper class to combine common functions of (currently) 
+Net::FTP, Net::SFTP, Net::FSP, Net::FTPSSL, Net::OpenSSH, Net:SSH2, and 
+Net::SFTP::Foreign into a single set of functions allowing one to switch 
+seemlessly between the two without having to make non-trivial code changes.  
+Only functionality common to all protocols has been implemented here with 
+the intent and invitation to add more functions and features and other 
+*FTP-ish modules in the future, as discovered or requested.
 
 =head1 PURPOSE
 
@@ -744,17 +747,18 @@ Returns the modification time in Perl "time" format of C<FILE>, or I<undef>
 on failure.  For FTP, the I<size> method is called, for SFTP:  I<do_stat>.  
 For <local>, perl's I<stat> function.
 
-=item Other methods
+=item method ( args )
 
 Even though C<Net::xFTP> is designed for commonality, it may occassionally 
 be necessary to call a method specific to a given protocol.  To do this,
 simply invoke the method as follows:
 
-$ftp->{xftp}->method ( args )
+$ftp->{xftp}->method ( args )    #DEPRECIATED with v1.00, use:
+$ftp->method ( args )
 
 Example:
 
- print "-FTP size of file = ".$ftp->{xftp}->size('/pub/myfile').".\n"
+ print "-FTP size of file = ".$ftp->method('size', '/pub/myfile').".\n"
 		if ($ftp->protocol() eq 'Net::FTP');
 
 =item sftpWarnings
@@ -767,6 +771,7 @@ methods.
 =head1 TODO
 
 Add a C<stat> method when this is supported in Net::FTP.
+Add any additional Net::*FTP-ish protocols as discovered or requested.
 
 =head1 BUGS
 
@@ -791,6 +796,16 @@ L<Net::FTP|Net::FTP>
 
 L<Net::SFTP|Net::SFTP>
 
+L<Net::SFTP::Foreign|Net::SFTP::Foreign>
+
+L<Net::FSP|Net::FSP>
+
+L<Net::FTPSSL|Net::FTPSSL>
+
+L<Net::OpenSSH|Net::OpenSSH>
+
+L<Net::SSH2|Net::SSH2>
+
 L<Net::SFTP::Constants|Net::SFTP::Constants>
 
 L<Net::SFTP::Attributes|Net::SFTP::Attributes>
